diff --git a/src/include/storage/s_lock.h b/src/include/storage/s_lock.h
index c6edb7a5e9e1e9fb6df912f0447bdead6ca68761..4104cf6c4cac918ca779612c258ea7369b98c04d 100644
--- a/src/include/storage/s_lock.h
+++ b/src/include/storage/s_lock.h
@@ -66,7 +66,7 @@
  * Portions Copyright (c) 1996-2010, PostgreSQL Global Development Group
  * Portions Copyright (c) 1994, Regents of the University of California
  *
- *	  $PostgreSQL: pgsql/src/include/storage/s_lock.h,v 1.170 2010/01/04 17:10:24 mha Exp $
+ *	  $PostgreSQL: pgsql/src/include/storage/s_lock.h,v 1.171 2010/01/05 11:06:28 mha Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -837,13 +837,13 @@ typedef LONG slock_t;
 #define SPIN_DELAY() spin_delay()
 
 /* If using Visual C++ on Win64, inline assembly is unavailable.
  * Use a __nop instrinsic instead of rep nop.
  */
 #if defined(_WIN64)
 static __forceinline void
 spin_delay(void)
 {
-	__nop();
+	_mm_pause();
 }
 #else
 static __forceinline void
@@ -837,13 +837,13 @@ typedef LONG slock_t;
 
 /* If using Visual C++ on Win64, inline assembly is unavailable.
- * Use a __nop instrinsic instead of rep nop.
+ * Use a _mm_pause instrinsic instead of rep nop.
  */
 #if defined(_WIN64)